***********
Facecast IO
***********

Unofficial API client to https://facecast.io service
####################################################

Installation
************

:pip: pip install facecast-io
:poetry: poetry add facecast-io

Usage
*****

::

    api = FacecastAPI(os.environ["FACECAST_USERNAME"], os.environ["FACECAST_PASSWORD"])

